@@ -160,11 +160,11 @@ ostree_validate_checksum_string (const char *sha256,
  * @out_ref: (out) (not nullable) (optional): Return location for the ref name
  * @error: Error
  *
- * Split a refspec like `gnome-ostree:gnome-ostree/buildmaster` or just
- * `gnome-ostree/buildmaster` into two parts. In the first case, @out_remote
- * will be set to `gnome-ostree`, and @out_ref to `gnome-ostree/buildmaster`.
+ * Split a refspec like `gnome-ostree:gnome-ostree/buildmain` or just
+ * `gnome-ostree/buildmain` into two parts. In the first case, @out_remote
+ * will be set to `gnome-ostree`, and @out_ref to `gnome-ostree/buildmain`.
  * In the second case (a local ref), @out_remote will be %NULL, and @out_ref
- * will be `gnome-ostree/buildmaster`. In both cases, %TRUE will be returned.
+ * will be `gnome-ostree/buildmain`. In both cases, %TRUE will be returned.
  *
  * Returns: %TRUE on successful parsing, %FALSE otherwise
  */
@@ -391,24 +391,18 @@ variant_to_lenprefixed_buffer (GVariant *variant)
   const guint32 variant_size_u32_be = GUINT32_TO_BE((guint32) variant_size);
 
   g_string_append_len (buf, (char*)&variant_size_u32_be, sizeof (variant_size_u32_be));
-  const gsize alignment_offset = sizeof (variant_size_u32_be);
 
   /* Write NULs for alignment. At the moment this is a constant 4 bytes (i.e.
-   * align to 8, since the length is 4 bytes). For now, I decided to keep some
-   * of the (now legacy) more generic logic here in case we want to revive it
-   * later.
+   * align to 8, since the length is 4 bytes).  If we ever change this, the
+   * logic is here:
    */
-  const guint alignment = 8;
-  const guchar padding_nuls[8] = {0, 0, 0, 0, 0, 0, 0, 0};
-  guint bits;
-  if (alignment == 8)
-    bits = alignment_offset & 7; /* mod 8 */
-  else
-    bits = alignment_offset & 3; /* mod 4 */
-  const guint padding_len = alignment - bits;
-
-  if (bits > 0)
-    g_string_append_len (buf, (char*)padding_nuls, padding_len);
+  // const gsize alignment_offset = sizeof (variant_size_u32_be);
+  // const guint bits = alignment_offset & 7; /* mod 8 */
+  // const guint padding_len = alignment - bits;
+  #define padding_len sizeof(guint32)
+  const guchar padding_nuls[padding_len] = {0, 0, 0, 0};
+  g_string_append_len (buf, (char*)padding_nuls, padding_len);
+  #undef padding_len
 
   g_string_append_len (buf, (char*)g_variant_get_data (variant), g_variant_get_size (variant));
   return g_string_free_to_bytes (g_steal_pointer (&buf));
@@ -418,18 +412,12 @@ variant_to_lenprefixed_buffer (GVariant *variant)
  * header_and_input_to_stream:
  * @file_header: A file header
  * @input: File raw content stream
- * @out_input: (out): Serialized object stream
- * @cancellable: Cancellable
- * @error: Error
  *
  * Combines @file_header and @input into a single stream.
  */
-static gboolean
+static GInputStream *
 header_and_input_to_stream (GBytes             *file_header,
-                            GInputStream       *input,
-                            GInputStream      **out_input,
-                            GCancellable       *cancellable,
-                            GError            **error)
+                            GInputStream       *input)
 {
   /* Our result stream chain */
   g_autoptr(GPtrArray) streams = g_ptr_array_new_with_free_func ((GDestroyNotify)g_object_unref);
@@ -444,10 +432,7 @@ header_and_input_to_stream (GBytes             *file_header,
     g_ptr_array_add (streams, g_object_ref (input));
 
   /* Return the result stream */
-  g_autoptr(GInputStream) ret_input = (GInputStream*)ostree_chain_input_stream_new (streams);
-  ot_transfer_out_value (out_input, &ret_input);
-
-  return TRUE;
+  return (GInputStream*)ostree_chain_input_stream_new (streams);
 }
 
 /* Convert file metadata + file content into an archive-format stream. */
@@ -468,11 +453,8 @@ _ostree_raw_file_to_archive_stream (GInputStream       *input,
       zlib_input = g_converter_input_stream_new (input, zlib_compressor);
     }
   g_autoptr(GBytes) file_header = _ostree_zlib_file_header_new (file_info, xattrs);
-  return header_and_input_to_stream (file_header,
-                                     zlib_input,
-                                     out_input,
-                                     cancellable,
-                                     error);
+  *out_input = header_and_input_to_stream (file_header, zlib_input);
+  return TRUE;
 }
 
 /**
@@ -566,12 +548,7 @@ ostree_raw_file_to_content_stream (GInputStream       *input,
                                    GError            **error)
 {
   g_autoptr(GBytes) file_header = _ostree_file_header_new (file_info, xattrs);
-  if (!header_and_input_to_stream (file_header,
-                                   input,
-                                   out_input,
-                                   cancellable,
-                                   error))
-    return FALSE;
+  *out_input = header_and_input_to_stream (file_header, input);
   if (out_length)
     *out_length = g_bytes_get_size (file_header) + g_file_info_get_size (file_info);
   return TRUE;
