@@ -34,12 +34,12 @@ extra_admin_tests=1
 cd ${test_tmpdir}
 rm httpd osdata testos-repo sysroot -rf
 setup_os_repository "archive" "sysroot.bootloader none"
-${CMD_PREFIX} ostree pull-local --repo=sysroot/ostree/repo --remote testos testos-repo testos/buildmaster/x86_64-runtime
+${CMD_PREFIX} ostree pull-local --repo=sysroot/ostree/repo --remote testos testos-repo testos/buildmain/x86_64-runtime
 # Test that configuring sysroot.bootloader="none" is a workaround for previous
 # grub2 bootloader issue (see https://github.com/ostreedev/ostree/issues/1774)
 mkdir -p sysroot/boot/grub2
 touch sysroot/boot/grub2/grub.cfg
-${CMD_PREFIX} ostree admin deploy --karg=root=LABEL=MOO --karg=quiet --os testos testos/buildmaster/x86_64-runtime > out.txt
+${CMD_PREFIX} ostree admin deploy --karg=root=LABEL=MOO --karg=quiet --os testos testos/buildmain/x86_64-runtime > out.txt
 assert_file_has_content out.txt "Bootloader updated.*"
 assert_file_has_content sysroot/boot/loader/entries/ostree-1-testos.conf 'options.* root=LABEL=MOO'
 assert_file_has_content sysroot/boot/ostree/testos-${bootcsum}/vmlinuz-3.6.0 'a kernel'
