@@ -31,16 +31,9 @@ if echo "$OSTREE_FEATURES" | grep --quiet --no-messages "devel"; then
 else
     devel_syms=
 fi
-if echo "$OSTREE_FEATURES" | grep --quiet --no-messages "experimental"; then
-  experimental_sym="${G_TEST_SRCDIR}/src/libostree/libostree-experimental.sym"
-  experimental_sections="${G_TEST_SRCDIR}/apidoc/ostree-experimental-sections.txt"
-else
-  experimental_sym=""
-  experimental_sections=""
-fi
 
 echo "Verifying all expected symbols are actually exported..."
-grep --no-filename ' ostree_[A-Za-z0-9_]*;' ${released_syms} ${devel_syms} ${experimental_sym} | sed -e 's,^ *\([A-Za-z0-9_]*\);,\1,' | sort -u > expected-symbols.txt
+grep --no-filename ' ostree_[A-Za-z0-9_]*;' ${released_syms} ${devel_syms} | sed -e 's,^ *\([A-Za-z0-9_]*\);,\1,' | sort -u > expected-symbols.txt
 eu-readelf -a ${G_TEST_BUILDDIR}/.libs/libostree-1.so | grep 'FUNC.*GLOBAL.*DEFAULT.*@@LIBOSTREE_' | sed -e 's,^.* \(ostree_[A-Za-z0-9_]*\)@@LIBOSTREE_[0-9A-Z_.]*,\1,' |sort -u > found-symbols.txt
 diff -u expected-symbols.txt found-symbols.txt
 
@@ -48,9 +41,6 @@ echo "Checking that the example symbol wasn't copy-pasted..."
 if test -f ${devel_syms}; then
   assert_file_has_content_once ${devel_syms} "someostree_symbol_deleteme"
 fi
-if test -f ${experimental_sym}; then
-  assert_not_file_has_content ${experimental_sym} "someostree_symbol_deleteme"
-fi
 assert_not_file_has_content ${released_syms} "someostree_symbol_deleteme"
 
 echo "ok exports"
@@ -59,14 +49,14 @@ echo "ok exports"
 grep -E -v '(ostree_cmd__private__)|(ostree_fetcher_config_flags_get_type)' found-symbols.txt > expected-documented.txt
 
 echo "Verifying all public symbols are documented:"
-grep --no-filename '^ostree_' ${G_TEST_SRCDIR}/apidoc/ostree-sections.txt $experimental_sections |sort -u > found-documented.txt
+grep --no-filename '^ostree_' ${G_TEST_SRCDIR}/apidoc/ostree-sections.txt |sort -u > found-documented.txt
 diff -u expected-documented.txt found-documented.txt
 
 echo 'ok documented symbols'
 
 # ONLY update this checksum in release commits!
 cat > released-sha256.txt <<EOF
-3e677623543b7fdc57b0e3d9c66eb477105b014411259762a328c1b5e82068f0  ${released_syms}
+d4eb6d642150d9285b399c7a429603124aeda4215d3f62b92ad3956f04dd2dfe  ${released_syms}
 EOF
 sha256sum -c released-sha256.txt
 
